import pathlib
from setuptools import setup
from robotidy.version import __version__


HERE = pathlib.Path(__file__).parent
README = (HERE / "README.md").read_text()
CLASSIFIERS = """
Development Status :: 5 - Production/Stable
License :: OSI Approved :: Apache Software License
Operating System :: OS Independent
Programming Language :: Python
Programming Language :: Python :: 3.7
Programming Language :: Python :: 3.8
Programming Language :: Python :: 3.9
Framework :: Robot Framework
Framework :: Robot Framework :: Tool
Topic :: Software Development :: Testing
Topic :: Software Development :: Quality Assurance
Topic :: Utilities
Intended Audience :: Developers
""".strip().splitlines()

setup(
    name="robotframework-tidy",
    version=__version__,
    description="Code autoformatter for Robot Framework",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/MarketSquare/robotframework-tidy",
    author="MarketSquare - Robot Framework community",
    author_email="bartek.hirsz@gmail.com",
    license="Apache License 2.0",
    platforms="any",
    classifiers=CLASSIFIERS,
    keywords="robotframework",
    packages=["robotidy"],
    include_package_data=True,
    python_requires=">=3.7",
    install_requires=[
        "click>=7.0",
        "colorama>=0.4.3",
        "packaging>=21.0",
        "pathspec>=0.9.0,<0.10.0",
        "robotframework>=4.0",
        "toml>=0.10.2",
    ],
    extras_requires={
        "dev": [
            "coverage",
            "invoke",
            "jinja2",
            "pylama_pylint",
            "pylama",
            "pytest",
        ],
        "doc": [
            "sphinx_rtd_theme",
            "sphinx",
        ],
    },
    entry_points={"console_scripts": ["robotidy=robotidy.cli:cli"]},
)
